==> james-project-3.7.6-source-release.zip: james-project/mailbox/api/src/main/java/org/apache/james/mailbox/Authorizator.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailbox;

import org.apache.james.core.Username;
import org.apache.james.mailbox.exception.MailboxException;

/**
 * Authenticates user credentials.
 */
public interface Authorizator {

    enum AuthorizationState {
        ALLOWED,
        NOT_ADMIN,
        UNKNOWN_USER
    }

    AuthorizationState canLoginAsOtherUser(Username userId, Username otherUserId) throws MailboxException;
}

==> james-project-3.9.0-source-release.zip: james-project/mailbox/api/src/main/java/org/apache/james/mailbox/Authorizator.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailbox;

import java.util.Collection;

import org.apache.james.core.Username;
import org.apache.james.mailbox.exception.MailboxException;

import com.google.common.collect.ImmutableList;

/**
 * Authenticates user credentials.
 */
public interface Authorizator {

    interface FluentAuthorizator {
        AuthorizationState canLoginAs(Username otherUserId) throws MailboxException;
    }

    enum AuthorizationState {
        ALLOWED,
        FORBIDDEN,
        UNKNOWN_USER
    }

    AuthorizationState canLoginAsOtherUser(Username userId, Username otherUserId) throws MailboxException;

    default FluentAuthorizator user(Username userId) {
        return otherUserId -> canLoginAsOtherUser(userId, otherUserId);
    }

    default Collection<Username> delegatedUsers(Username username) {
        return ImmutableList.of();
    }
}
